API
===

SatNOGS Network API is a REST API to get scheduled jobs and post observation data.
This document explains how to use the API to retrieve and post data for your application.


Using API Data
--------------

API access is open to anyone.
All API data are freely distributed under the `CC BY-SA`_ license.


API Reference
-------------

The SatNOGS Network API is described by the `SatNOGS Network OpenAPI document`_ which
follows the `OpenAPI specification`_.


Interactive API documentation
-----------------------------

Based on the OpenAPI document for SatNOGS Network, an `interactive API documentation`_ is available,
auto-generated by the `OpenAPI generator`_.

.. _CC BY-SA: https://creativecommons.org/licenses/by-sa/4.0/
.. _OpenAPI specification: https://spec.openapis.org/oas/latest.html
.. _OpenAPI generator: https://github.com/openapitools/openapi-generator
.. The following hyperlink targets are generated dynamically by sphinx:
   - "SatNOGS Network OpenAPI document"
   - "interactive API documentation"
